import { createContext, useContext, useMemo } from 'react';
import { createMaterialStore, MaterialStoreType } from '../../store/simulation/useMaterialStore';

type SceneContextValue = {
    materialStore: MaterialStoreType;
    // Add other stores here if needed
};

const SceneContext = createContext<SceneContextValue | null>(null);

export function SceneProvider({ children }: { readonly children: React.ReactNode }) {
    const materialStore = useMemo(() => createMaterialStore(), []);
    const contextValue = useMemo(() => ({ materialStore }), [materialStore]);

    return (
        <SceneContext.Provider value={contextValue}>
            {children}
        </SceneContext.Provider>
    );
}

// Base hook to get the context
export function useSceneContext() {
    const context = useContext(SceneContext);
    if (!context) {
        throw new Error('useSceneContext must be used within a SceneProvider');
    }
    return context;
}
